netapp_ontap.models.port_statistics_packet_counters API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.port_statistics_packet_counters`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class PortStatisticsPacketCountersSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the PortStatisticsPacketCounters object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `discards GET`

    Total number of discarded packets.

    Example: 100

  `errors GET`

    Number of packet errors.

    Example: 200

  `packets GET`

    Total packet count.

    Example: 500